A Python module to send SMS via Yesss.at's website
==================================================

This module allows for sending SMS via `yesss.at's website
<https://yesss.at>`.

Regular rates apply, yesss.at account or contract needed.
